pub fn clear_blur_cache()Expand description
Drop every cached blurred backdrop on this thread — for a render context that is being torn down, whose images must not outlive it.
pub fn clear_blur_cache()Drop every cached blurred backdrop on this thread — for a render context that is being torn down, whose images must not outlive it.